package com.honksandsirens;

import java.awt.*;
import com.softsynth.jsyn.*;

/**
 * 
 * FOF - sends pulses to five parallel filters
 * used for FOF speech synthesis
 *
 * @author James Forrest, 2.13.00
 * (C) 2000, James Forrest
 *
 * TD : BUILD BUTTERWORTH BAND-PASS FILTER
 */
 
public class FOF extends SynthCircuit {

	public static final	int	NUM_FORMANTS = 3;
	PulseOscillator		pulseOsc;
													
 	public Filter_2o2p2z				filters[] = new Filter_2o2p2z[NUM_FORMANTS];
	BusWriter						filterMixers[] = new BusWriter[NUM_FORMANTS];
	BusReader						filterAdder;
	
	public	SynthInput					pulseFreq;
	public	SynthInput					pulseAmp;
								
	public FOF() {
		//add oscillator to circuit and initialize
		add(pulseOsc = new PulseOscillator());
		add(filterAdder = new BusReader());
		
		//for loop to initialize and connect array of filters in parallel
		for (int i=0; i<NUM_FORMANTS; i++) {

			//initialize and add filter
			add(filters[i] = new Filter_2o2p2z());
			
			//connect oscillator to input of filter
			
			pulseOsc.output.connect(filters[i].input);
						
			//initialize and add filter bus writer & bus reader
			add(filterMixers[i] = new BusWriter());
						
			//connect filter to bus
			filters[i].output.connect (filterMixers[i].input);
			
			//connect writer bus to reader bus
			filterMixers[i].busOutput.connect (filterAdder.busInput);
			
			//connect reader bus to output
			
			
			//add external ports
			
			addPort(pulseFreq = pulseOsc.frequency);
			addPort(pulseAmp = pulseOsc.amplitude);
			addPort(output = filterAdder.output);
			
			
		}
	}
	
	
}
		
		