package com.honksandsirens;

import com.softsynth.jsyn.*;
import java.awt.*;

/**
 * StagedVowelizerApplet.java
 * 
 * Send an impulse oscillator through a stagedVowelizer.
 * 
 * Set the rate of vowel transition
 * 
 * Hit buttons to transition from vowel to vowel
 * 
 * @author Nick Didkovsky, didkovn@mail.rockefeller.edu
 */

public class StagedVowelizerApplet extends java.applet.Applet
{
	StagedVowelizer fof;
        ImpulseOscillatorBL osc;
	LineOut        out;

/* Setup GUI */
public void init() {
	
}

public void start() {
    setLayout(new BorderLayout());
        Synth.startEngine(0);
        out = new LineOut();
    	fof = new StagedVowelizer();
    	osc = new ImpulseOscillatorBL();
    	osc.output.connect(fof.input);
    	osc.frequency.set(100);
        osc.amplitude.set(1.0);
    	osc.output.connect(0, fof.input, 0);
    	fof.output.connect(0, out.input, 0);
    	fof.output.connect(0, out.input, 1);
    	fof.amplitude.set(10.0);    // fof needs big amp!
    	osc.start();
    	fof.start();
    	out.start();

        add("South", new StagedVowelizerPanel(fof));

        java.awt.Panel p = new java.awt.Panel();
        p.setLayout(new java.awt.GridLayout(0, 1));
        p.add(new Label("Noise source controls", Label.CENTER));
        p.add(new com.softsynth.jsyn.view11x.PortFader(osc.frequency, 60, 20, 200.0));
        p.add(new com.softsynth.jsyn.view11x.PortFader(osc.amplitude, 1.0, 0.0, 1.0));
        add("North", p);

	getParent().validate();
	getToolkit().sync();
}
	

public void stop() {
    removeAll();
    Synth.setTrace( Synth.SILENT );
    Synth.stopEngine();
}

/* Can be run as either an application or as an applet. */
    public static void main(String args[])
	{
		StagedVowelizerApplet applet = new StagedVowelizerApplet();
		AppletFrame frame = new AppletFrame("Play vowels with FOF filters", applet);
		frame.setSize(400, 350);
		frame.show();
		frame.test(); 
	}


}
